%global sover 30

Summary:       Provides the specification and reference implementation of the EXR file format
Name:          openexr
Version:       3.1.11
Release:       2%{?dist}
License:       BSD
URL:           https://www.openexr.com/
Source0:       https://github.com/AcademySoftwareFoundation/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

# add include cstdint for exrcheck
Patch0001:     openexr-cstdint.patch

BuildRequires: cmake gcc gcc-c++ boost-devel imath-devel python%{python3_pkgversion}-devel zlib-devel

Provides:      OpenEXR = %{version}-%{release}

%description
OpenEXR is an open-source high-dynamic-range floating-point image file format for high-quality image
processing and storage. This document presents a brief overview of OpenEXR and explains concepts
that are specific to this format.

This package containes the binaries for OpenEXR.


%package libs
Summary:        OpenEXR Libraries
Provides:       OpenEXR-libs = %{version}-%{release}

%description libs
OpenEXR is an open-source high-dynamic-range floating-point image file format for high-quality image
processing and storage. This document presents a brief overview of OpenEXR and explains concepts
that are specific to this format.

OpenEXR Features:

* High dynamic range and color precision.  Support for 16-bit floating-point,
* 32-bit floating-point, and 32-bit integer pixels.
* Multiple image compression algorithms, both lossless and lossy. Some of the included codecs can
  achieve 2:1 lossless compression ratios on images with film grain.  The lossy codecs have been tuned
  for visual quality and decoding performance.
* Extensibility. New compression codecs and image types can easily be added by extending the C++
  classes included in the OpenEXR software distribution.  New image attributes (strings, vectors,
  integers, etc.) can be added to OpenEXR image headers without affecting backward compatibility with
  existing OpenEXR applications.
* Support for stereoscopic image workflows and a generalization to multi-views.
  * Flexible support for deep data: pixels can store a variable-length list of samples and, thus, it
  is possible to store multiple values at different depths for each pixel. Hard surfaces and
  volumetric data representations are accommodated.
* Multipart: ability to encode separate, but related, images in one file.  This allows for access to
  individual parts without the need to read other parts in the file.
* Versioning: OpenEXR source allows for user configurable C++ namespaces to provide protection when
  using multiple versions of the library in the same process space.

The IlmBase Library:

Also a part of OpenEXR, the IlmBase library is a basic, light-weight, and efficient representation
of 2D and 3D vectors and matrices and other simple but useful mathematical objects, functions, and
data types common in computer graphics applications, including the “half” 16-bit floating-point
type.


%package devel
Summary:        Development files for %{name}
Requires:       %{name}-libs = %{version}-%{release}
Provides:       OpenEXR-devel = %{version}-%{release}
Provides:       ilmbase-devel = %{version}-%{release}

%description devel
Provides the specification and reference implementation of the EXR file format

%prep
%autosetup -n %{name}-%{version} -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%check
%ifarch aarch64
# https://github.com/AcademySoftwareFoundation/openexr/issues/1460
EXCLUDE_REGEX='DWA[AB]Compression'
%endif
%ctest --exclude-regex "$EXCLUDE_REGEX"

%files
%{_bindir}/*

%files libs
%license LICENSE.md
%doc CHANGES.md CONTRIBUTING.md GOVERNANCE.md SECURITY.md CODE_OF_CONDUCT.md CONTRIBUTORS.md README.md
%{_libdir}/*.so.%{sover}*

%files devel
%{_docdir}/OpenEXR/
%{_includedir}/OpenEXR/
%{_libdir}/*.so
%{_libdir}/cmake/OpenEXR/
%{_libdir}/pkgconfig/OpenEXR.pc

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.11-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 22 2023 Shuo Wang <abushwang@tencent.com> - 3.1.11-1
- update to 3.1.11

* Tue Aug 01 2023 rockerzhu rockerzhu@tencent.com - 3.1.4-4
- Rebuilt for boost 1.82.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.4-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.4-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Feb 3 2023 Shuo Wang <abushwang@tencent.com> - 3.1.4-1
- initial build
